@@ -19,7 +19,7 @@ attach.all <- function(x, overwrite = NA, name = "attach.all"){
 }
 
 attach.bugs <- function (x, overwrite = NA){
-  if(class(x) != "bugs")
+  if(!inherits(x, "bugs"))
     stop("attach.all() requires a bugs object.")
   if("bugs.sims" %in% search()){
     detach("bugs.sims")}
